@@ -27,6 +27,8 @@
 #include <ksystemtrayicon.h>
 #include <kfiledialog.h>
 #include <kglobal.h>
+#include <ktoolinvocation.h>
+#include <kstandardguiitem.h>
 
 class KTimerJobItem : public QTreeWidgetItem {
 public:
@@ -104,13 +106,16 @@ KTimerPref::KTimerPref( QWidget *parent)
     m_start->setIcon( KIcon("arrow-right") );
 
     // create tray icon
-    KSystemTrayIcon *tray = new KSystemTrayIcon( this );
+    KSystemTrayIcon *tray = new KSystemTrayIcon( "ktimer",this );
     tray->show();
-    tray->setIcon( KIcon( "ktimer" ) );
+
+    // set help button gui item
+    m_help->setGuiItem(KStandardGuiItem::help());
 
     // connect
     connect( m_add, SIGNAL(clicked()), SLOT(add()) );
     connect( m_remove, SIGNAL(clicked()), SLOT(remove()) );
+    connect( m_help, SIGNAL(clicked()), SLOT(help()) );
     connect( m_list, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)),
              SLOT(currentChanged(QTreeWidgetItem *, QTreeWidgetItem *)) );
     loadJobs( KGlobal::config().data() );
@@ -162,6 +167,10 @@ void KTimerPref::remove()
     m_list->update();
 }
 
+void KTimerPref::help()
+{
+    KToolInvocation::invokeHelp();
+}
 
 // note, don't use old, but added it so we can connect to the new one
 void KTimerPref::currentChanged( QTreeWidgetItem *i , QTreeWidgetItem * /* old */)
@@ -254,7 +263,8 @@ void KTimerPref::done(int result) {
 
 void KTimerPref::saveJobs( KConfig *cfg )
 {
-	for (int num = 0; num < m_list->topLevelItemCount(); ++num)
+	const int nbList=m_list->topLevelItemCount();
+	for (int num = 0; num < nbList; ++num)
 	{
 		KTimerJobItem *item = static_cast<KTimerJobItem*>(m_list->topLevelItem(num));
         item->job()->save( cfg, QString("Job%1").arg( num ) );
@@ -270,7 +280,7 @@ void KTimerPref::saveJobs( KConfig *cfg )
 
 void KTimerPref::loadJobs( KConfig *cfg )
 {
-    int num = cfg->group("Jobs").readEntry( "Number", 0 );
+    const int num = cfg->group("Jobs").readEntry( "Number", 0 );
     for( int n=0; n<num; n++ ) {
             KTimerJob *job = new KTimerJob;
             KTimerJobItem *item = new KTimerJobItem( job, m_list );
@@ -521,8 +531,8 @@ void KTimerJob::timeout()
 void KTimerJob::processExited(int, QProcess::ExitStatus status)
 {
 	QProcess * proc = static_cast<QProcess*>(sender());
-    bool ok = status==0;
-    int i = d->processes.indexOf( proc);
+    const bool ok = status==0;
+    const int i = d->processes.indexOf( proc);
     if (i != -1)
         delete d->processes.takeAt(i);
 
@@ -540,12 +550,12 @@ void KTimerJob::fire()
         d->processes.append( proc );
         connect( proc, SIGNAL(finished(int, QProcess::ExitStatus)),
                  SLOT(processExited(int, QProcess::ExitStatus)) );
-        if (!d->command.isEmpty()) {
+        if (!d->command.simplified ().isEmpty()) {
 	        proc->start(d->command);
 	        emit fired( this );
         }
         if(proc->state() == QProcess::NotRunning) {
-            int i = d->processes.indexOf( proc);
+            const int i = d->processes.indexOf( proc);
             if (i != -1)
                 delete d->processes.takeAt(i);
             emit error( this );
